
/* Generated data (by glib-mkenums) */

/*
 * Copyright (C) 2016 Canonical Ltd.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2 or version 3 of the License.
 * See http://www.gnu.org/copyleft/lgpl.html the full text of the license.
 */

#ifndef __SNAPD_ENUM_TYPES_H__
#define __SNAPD_ENUM_TYPES_H__

#if !defined(__SNAPD_GLIB_INSIDE__) && !defined(SNAPD_COMPILATION)
#error "Only <snapd-glib/snapd-glib.h> can be included directly."
#endif

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "./snapd-client.h" */
GType snapd_error_get_type (void) G_GNUC_CONST;
#define SNAPD_TYPE_ERROR (snapd_error_get_type())

GType snapd_find_flags_get_type (void) G_GNUC_CONST;
#define SNAPD_TYPE_FIND_FLAGS (snapd_find_flags_get_type())

/* enumerations from "./snapd-snap.h" */
GType snapd_confinement_get_type (void) G_GNUC_CONST;
#define SNAPD_TYPE_CONFINEMENT (snapd_confinement_get_type())

GType snapd_snap_type_get_type (void) G_GNUC_CONST;
#define SNAPD_TYPE_SNAP_TYPE (snapd_snap_type_get_type())

GType snapd_snap_status_get_type (void) G_GNUC_CONST;
#define SNAPD_TYPE_SNAP_STATUS (snapd_snap_status_get_type())

G_END_DECLS

#endif /* !__SNAPD_ENUM_TYPES_H__ */

/* Generated data ends here */

